==> org.eclipse.riena.navigation.ui.swt.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/internal/navigation/ui/swt/handlers/CloseModule.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.internal.navigation.ui.swt.handlers;

import java.util.List;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;

import org.eclipse.riena.navigation.ApplicationNodeManager;
import org.eclipse.riena.navigation.IApplicationNode;
import org.eclipse.riena.navigation.IModuleGroupNode;
import org.eclipse.riena.navigation.IModuleNode;
import org.eclipse.riena.navigation.INavigationNode;

/**
 * Close the currently active module.
 */
public class CloseModule extends AbstractNavigationHandler {

	public Object execute(ExecutionEvent event) throws ExecutionException {
		// assumes there is only one application node
		IApplicationNode application = ApplicationNodeManager.getApplicationNode();
		IModuleNode module = findModule(application);
		if (module != null && module.isClosable()) {
			INavigationNode<?> previous = findPreviousModule(application);
			if (previous != null) {
				previous.activate();
			}
			module.dispose();
		}
		return null;
	}

	// helping methods
	//////////////////

	private INavigationNode<?> findPreviousModule(IApplicationNode application) {
		IModuleNode[] modules = collectModules(application);
		return findPreviousNode(modules, false);
	}

	/**
	 * Not API; public for testing only.
	 */
	@SuppressWarnings("unchecked")
	public final IModuleNode findModule(IApplicationNode application) {
		IModuleNode result = null;
		IModuleGroupNode moduleGroup = findModuleGroup(application);
		if (moduleGroup != null) {
			INavigationNode<?> module = findActive((List) moduleGroup.getChildren());
			if (module instanceof IModuleNode) {
				result = (IModuleNode) module;
			}
		}
		return result;
	}

}

==> org.eclipse.riena.navigation.ui.swt.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/internal/navigation/ui/swt/handlers/CloseModule.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.internal.navigation.ui.swt.handlers;

import java.util.List;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;

import org.eclipse.riena.navigation.ApplicationNodeManager;
import org.eclipse.riena.navigation.IApplicationNode;
import org.eclipse.riena.navigation.IModuleGroupNode;
import org.eclipse.riena.navigation.IModuleNode;
import org.eclipse.riena.navigation.INavigationNode;

/**
 * Close the currently active module.
 */
public class CloseModule extends AbstractNavigationHandler {

	public Object execute(final ExecutionEvent event) throws ExecutionException {
		// assumes there is only one application node
		final IApplicationNode application = ApplicationNodeManager.getApplicationNode();
		final IModuleNode module = findModule(application);
		if (module != null && module.isClosable()) {
			final INavigationNode<?> previous = findPreviousModule(application);
			if (previous != null) {
				previous.activate();
			}
			module.dispose();
		}
		return null;
	}

	// helping methods
	//////////////////

	private INavigationNode<?> findPreviousModule(final IApplicationNode application) {
		final IModuleNode[] modules = collectModules(application);
		return findPreviousNode(modules, false);
	}

	/**
	 * Not API; public for testing only.
	 */
	@SuppressWarnings("unchecked")
	public final IModuleNode findModule(final IApplicationNode application) {
		IModuleNode result = null;
		final IModuleGroupNode moduleGroup = findModuleGroup(application);
		if (moduleGroup != null) {
			final INavigationNode<?> module = findActive((List) moduleGroup.getChildren());
			if (module instanceof IModuleNode) {
				result = (IModuleNode) module;
			}
		}
		return result;
	}

}
